@@ -5,7 +5,7 @@ import (
 	"testing"
 
 	"github.com/snyk/driftctl/enumeration/resource"
-	"github.com/snyk/driftctl/enumeration/resource/aws"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 func TestAwsInstanceEIP_Execute(t *testing.T) {
