@@ -3,7 +3,7 @@ package middlewares
 import (
 	"testing"
 
-	"github.com/snyk/driftctl/enumeration/resource/aws"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 
 	"github.com/snyk/driftctl/enumeration/resource"
 )
