@@ -1,15 +1,14 @@
 package middlewares
 
 import (
-	"github.com/snyk/driftctl/enumeration/terraform"
 	"strings"
 	"testing"
 
 	"github.com/aws/aws-sdk-go/aws/awsutil"
 	"github.com/r3labs/diff/v2"
-	"github.com/snyk/driftctl/enumeration/resource/aws"
-
 	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 func TestIamPolicyAttachmentExpander_Execute(t *testing.T) {
@@ -20,13 +19,13 @@ func TestIamPolicyAttachmentExpander_Execute(t *testing.T) {
 	tests := []struct {
 		name     string
 		args     resources
-		mocks    func(*terraform.MockResourceFactory)
+		mocks    func(*dctlresource.MockResourceFactory)
 		expected resources
 		wantErr  bool
 	}{
 		{
 			name: "Split users and ReId",
-			mocks: func(factory *terraform.MockResourceFactory) {
+			mocks: func(factory *dctlresource.MockResourceFactory) {
 				factory.On(
 					"CreateAbstractResource",
 					aws.AwsIamPolicyAttachmentResourceType,
@@ -186,7 +185,7 @@ func TestIamPolicyAttachmentExpander_Execute(t *testing.T) {
 		},
 		{
 			name: "Split Roles and ReId",
-			mocks: func(factory *terraform.MockResourceFactory) {
+			mocks: func(factory *dctlresource.MockResourceFactory) {
 				factory.On(
 					"CreateAbstractResource",
 					aws.AwsIamPolicyAttachmentResourceType,
@@ -346,7 +345,7 @@ func TestIamPolicyAttachmentExpander_Execute(t *testing.T) {
 		},
 		{
 			name: "Split Groups and ReId",
-			mocks: func(factory *terraform.MockResourceFactory) {
+			mocks: func(factory *dctlresource.MockResourceFactory) {
 				factory.On(
 					"CreateAbstractResource",
 					aws.AwsIamPolicyAttachmentResourceType,
@@ -508,7 +507,7 @@ func TestIamPolicyAttachmentExpander_Execute(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 
-			factory := &terraform.MockResourceFactory{}
+			factory := &dctlresource.MockResourceFactory{}
 			if tt.mocks != nil {
 				tt.mocks(factory)
 			}
