@@ -1,22 +1,21 @@
 package aws_test
 
 import (
+	"github.com/snyk/driftctl/enumeration/remote/aws/repository"
+	"github.com/snyk/driftctl/enumeration/remote/cache"
 	"strings"
 	"testing"
 	"time"
 
 	"github.com/sirupsen/logrus"
-	"github.com/snyk/driftctl/pkg/remote/cache"
-
-	"github.com/snyk/driftctl/pkg/remote/aws/repository"
 	"github.com/snyk/driftctl/test"
 
 	"github.com/aws/aws-sdk-go/service/sns"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/r3labs/diff/v2"
+	awsresources "github.com/snyk/driftctl/enumeration/resource/aws"
 	"github.com/snyk/driftctl/pkg/analyser"
-	awsresources "github.com/snyk/driftctl/pkg/resource/aws"
 	"github.com/snyk/driftctl/test/acceptance"
 	"github.com/snyk/driftctl/test/acceptance/awsutils"
 )
